/*******************************************************************************
* File Name: ISRatodDone.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <ISRatodDone.h>

#if !defined(ISRatodDone__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ISRatodDone_intc` */
    
#include <project.h>

extern uint16 volatile Deadtime_Ans;		// Deadtime ADC Answer
extern uint8 volatile  AtoDdoneflg;         // Flag to indicate EOC, end of conversion for A/D

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: ISRatodDone_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_Start(void)
{
    /* For all we know the interrupt is active. */
    ISRatodDone_Disable();

    /* Set the ISR to point to the ISRatodDone Interrupt. */
    ISRatodDone_SetVector(&ISRatodDone_Interrupt);

    /* Set the priority. */
    ISRatodDone_SetPriority((uint8)ISRatodDone_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISRatodDone_Enable();
}


/*******************************************************************************
* Function Name: ISRatodDone_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    ISRatodDone_Disable();

    /* Set the ISR to point to the ISRatodDone Interrupt. */
    ISRatodDone_SetVector(address);

    /* Set the priority. */
    ISRatodDone_SetPriority((uint8)ISRatodDone_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISRatodDone_Enable();
}


/*******************************************************************************
* Function Name: ISRatodDone_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_Stop(void)
{
    /* Disable this interrupt. */
    ISRatodDone_Disable();

    /* Set the ISR to point to the passive one. */
    ISRatodDone_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: ISRatodDone_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for ISRatodDone.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(ISRatodDone_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START ISRatodDone_Interrupt` */
    
    int32 Tempval;
    Tempval = ADC_DelSig_GetResult32();  	   
	Deadtime_Ans = ( Tempval >= 0 ) ? (uint16) Tempval : 0;        // A/D output < 0, the force it to 0
    AtoDdoneflg = 1;
    ISRatodDone_ClearPending( );                                    // Clear the interrupt

    /* `#END` */
}


/*******************************************************************************
* Function Name: ISRatodDone_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling ISRatodDone_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use ISRatodDone_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)ISRatodDone__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: ISRatodDone_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress ISRatodDone_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)ISRatodDone__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: ISRatodDone_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling ISRatodDone_Start
*   or ISRatodDone_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   ISRatodDone_Start or ISRatodDone_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_SetPriority(uint8 priority)
{
    *ISRatodDone_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: ISRatodDone_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 ISRatodDone_GetPriority(void)
{
    uint8 priority;


    priority = *ISRatodDone_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: ISRatodDone_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_Enable(void)
{
    /* Enable the general interrupt. */
    *ISRatodDone_INTC_SET_EN = ISRatodDone__INTC_MASK;
}


/*******************************************************************************
* Function Name: ISRatodDone_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 ISRatodDone_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*ISRatodDone_INTC_SET_EN & (uint32)ISRatodDone__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: ISRatodDone_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_Disable(void)
{
    /* Disable the general interrupt. */
    *ISRatodDone_INTC_CLR_EN = ISRatodDone__INTC_MASK;
}


/*******************************************************************************
* Function Name: ISRatodDone_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_SetPending(void)
{
    *ISRatodDone_INTC_SET_PD = ISRatodDone__INTC_MASK;
}


/*******************************************************************************
* Function Name: ISRatodDone_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ISRatodDone_ClearPending(void)
{
    *ISRatodDone_INTC_CLR_PD = ISRatodDone__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
